|
Efficient closures
|
|
4
|
1324
|
June 13, 2020
|
|
Why are my linear interpolations 10x faster in MATLAB?
|
|
26
|
4133
|
June 12, 2020
|
|
Large CPU time overhead RK4 ODE solver for parabolic problem
|
|
15
|
975
|
June 12, 2020
|
|
Why there are different execution times for same function calls
|
|
4
|
943
|
June 12, 2020
|
|
Simple way to precompile standard package for batch
|
|
14
|
1111
|
June 11, 2020
|
|
Why sortperm(Int32[]) return Int64[]
|
|
1
|
396
|
June 11, 2020
|
|
Is the best number of threads used in parallel computing by using distribute 4?
|
|
4
|
1518
|
June 11, 2020
|
|
Is it possible to force use Int32, instead of Int64
|
|
14
|
3217
|
June 11, 2020
|
|
Using a DataFrame to calculate another column in a separate DataFrame
|
|
6
|
949
|
June 10, 2020
|
|
Why `mean` with `dims` argument is so slow?
|
|
4
|
689
|
June 10, 2020
|
|
Can't figure out why dynamic dispatch is occuring
|
|
6
|
740
|
June 9, 2020
|
|
Improving a Program Implementing findall Function
|
|
1
|
415
|
June 7, 2020
|
|
Parallel reductions on CPUs with different speeds
|
|
6
|
839
|
June 5, 2020
|
|
Best performance using dictionaries, functions and modules
|
|
8
|
1099
|
June 5, 2020
|
|
10x slowdown when passing function as argument
|
|
15
|
2575
|
June 4, 2020
|
|
Efficient merging of large dictionaries
|
|
4
|
1267
|
June 4, 2020
|
|
Coverage test is extremely slow on multiple threads
|
|
6
|
919
|
June 4, 2020
|
|
Performance issues - Comparison with Matlab
|
|
6
|
1054
|
June 2, 2020
|
|
Speed of vectorized vs for-loops using Zygote
|
|
20
|
2545
|
June 1, 2020
|
|
Improving Performance of For-Loop and Matrix Multiplication for Time Integration Solver
|
|
8
|
1267
|
June 1, 2020
|
|
Function control flow
|
|
22
|
1882
|
May 31, 2020
|
|
Sum over BigInt better performance without generator
|
|
3
|
612
|
May 31, 2020
|
|
Tuple or immutable struct as function argument regarding speed and optimization
|
|
10
|
2409
|
May 29, 2020
|
|
Need help with performance in a very large loop
|
|
28
|
1787
|
May 28, 2020
|
|
Help me make this O(n^2) function faster?
|
|
8
|
1579
|
May 27, 2020
|
|
Integer parametric typed struct much slower than concrete struct
|
|
6
|
661
|
May 26, 2020
|
|
Inverse of symmetric Matrix does not give proper output
|
|
3
|
548
|
May 26, 2020
|
|
Out of order branch execution prediction slower?
|
|
17
|
1364
|
May 26, 2020
|
|
Why isn't 10^6 evaluated at compile time?
|
|
21
|
1473
|
May 25, 2020
|
|
The best linear solver for sparse bandedblockbandedmatricies
|
|
30
|
6173
|
May 24, 2020
|